from testit_python_commons.services import AdapterManager
from testit_python_commons.step import Step
from .utils import (
    form_test,
    get_outcome
)


class AdapterListener(object):
    __executable_test = None

    def __init__(self, adapter_manager: AdapterManager):
        self.__adapter_manager = adapter_manager

    def start_launch(self):
        test_run_id = self.__adapter_manager.get_test_run_id()

        self.__adapter_manager.set_test_run_id(test_run_id)

    def get_tests_for_launch(self):
        return self.__adapter_manager.get_autotests_for_launch()

    def start_test(self, test):
        self.__executable_test = form_test(test)

    def set_outcome(self, event):
        outcome, message, trace = get_outcome(event)

        self.__executable_test['outcome'] = outcome
        self.__executable_test['message'] = message
        self.__executable_test['traces'] = trace

    def stop_test(self):
        test_steps, test_results_steps = Step.get_steps_data()

        self.__executable_test['steps'] = test_steps
        self.__executable_test['stepResults'] = test_results_steps

        self.__adapter_manager.write_test(self.__executable_test)
        self.__executable_test = None



from nose2.events import Plugin

from testit_python_commons.services import TmsPluginManager

from .listener import AdapterListener


class TmsPlugin(Plugin):
    configSection = 'testit'
    commandLineSwitch = (None, 'testit', 'TMS adapter for Nose')
    __listener = None
    __tests_for_launch = None

    def __init__(self, *args, **kwargs):
        super(TmsPlugin, self).__init__(*args, **kwargs)

    def startTestRun(self, event):
        self.__listener = AdapterListener(
            TmsPluginManager.get_adapter_manager())

        TmsPluginManager.get_plugin_manager().register(self.__listener)

        self.__listener.start_launch()
        self.__tests_for_launch = self.__listener.get_tests_for_launch()

    def startTest(self, event):
        self.__listener.start_test(event.test)

    def stopTest(self, event):
        self.__listener.stop_test()

    def testOutcome(self, event):
        self.__listener.set_outcome(event)



from setuptools import setup, find_packages

setup(
    name='testit-adapter-nose',
    version='2.1.2',
    description='Nose adapter for Test IT',
    long_description=open('README.md', "r").read(),
    long_description_content_type="text/markdown",
    url='https://github.com/testit-tms/adapters-python/',
    author='Integration team',
    author_email='integrations@testit.software',
    license='Apache-2.0',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    py_modules=['testit_adapter_nose'],
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    install_requires=['attrs', 'nose2', 'testit-python-commons==2.1.2'],
    entry_points={
            'nose.plugins.0.10': [
                'testit_adapter_nose = testit_adapter_nose.plugin:TmsPlugin',
            ]
    }
)
